==> ui-react-1.0.84.tgz: package/esm/Parallax/Parallax.js <==
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
const _excluded = ["value", "root", "render", "rate", "scrollDirection", "transformDirection", "transition", "disabled", "className", "style", "children"];
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
import React from 'react';
import { is, clamp, unique } from '@onesy/utils';
import { classNames, style as styleMethod, useOnesyTheme } from '@onesy/style-react';
import useMediaQuery from '../useMediaQuery';
import { valueBreakpoints, staticClassName } from '../utils';
const useStyle = styleMethod(theme => ({
  root: {}
}), {
  name: 'onesy-Parallax'
});
const Parallax = /*#__PURE__*/React.forwardRef((props_, ref) => {
  const theme = useOnesyTheme();
  const props = React.useMemo(() => _objectSpread(_objectSpread(_objectSpread({}, theme?.ui?.elements?.all?.props?.default), theme?.ui?.elements?.onesyParallax?.props?.default), props_), [props_]);
  const {
      value: value_,
      // element
      root = window.document,
      render,
      // value or a method
      rate = -1,
      scrollDirection = 'vertical',
      transformDirection = 'vertical',
      transition = `transform ${theme.transitions.duration.xxs}`,
      disabled: disabled_,
      className,
      style,
      children
    } = props,
    other = _objectWithoutProperties(props, _excluded);
  const {
    classes
  } = useStyle();
  const refs = {
    root: React.useRef(undefined),
    value: React.useRef(undefined),
    scrollDirection: React.useRef(undefined),
    transformDirection: React.useRef(undefined),
    rate: React.useRef(undefined),
    disabled: React.useRef(undefined)
  };
  const keys = React.useMemo(() => {
    const result = [];
    const items = [disabled_];
    items.forEach(item => {
      if (is('object', item)) Object.keys(item).filter(key => theme.breakpoints.media[key]).forEach(key => result.push(key));
    });
    return unique(result);
  }, [disabled_]);
  const breakpoints = {};
  keys.forEach(key => {
    breakpoints[key] = useMediaQuery(theme.breakpoints.media[key], {
      element: refs.root.current
    });
  });
  const disabled = valueBreakpoints(disabled_, false, breakpoints, theme);
  const [value, setValue] = React.useState(0);
  refs.value.current = value;
  refs.scrollDirection.current = scrollDirection;
  refs.transformDirection.current = transformDirection;
  refs.rate.current = rate;
  refs.disabled.current = disabled;
  const update = () => {
    let valueNew;
    if (refs.disabled.current) return;

    // Element rect
    const rect = refs.root.current.getBoundingClientRect();

    // Viewport
    if (
    // Vertically
    (
    // Element in view
    rect.y >= 0 && rect.bottom <= window.innerHeight ||
    // Element y out of view, but bottom in view
    rect.y < 0 && rect.bottom >= 0 ||
    // Element bottom out of view, but y in view
    rect.bottom > window.innerHeight && rect.y <= window.innerHeight) && (
    // Horizontally

    // Element in view
    rect.x >= 0 && rect.right <= window.innerWidth ||
    // Element x out of view, but right in view
    rect.x < 0 && rect.right >= 0 ||
    // Element right out of view, but x in view
    rect.right > window.innerWidth && rect.y <= window.innerWidth)) {
      const padding = Math.abs((window.innerHeight - rect.height) / 2);
      const max = rect.height + padding;
      valueNew = ((window.innerHeight - rect.y) / max - 1) * 100;
    }
    if (valueNew !== undefined && valueNew !== refs.value.current) setValue(clamp(valueNew, -100, 100));
  };
  React.useEffect(() => {
    // Update on init
    if (!props.hasOwnProperty('value')) update();
  }, []);
  React.useEffect(() => {
    if (!props.hasOwnProperty('value') && root?.addEventListener) root.addEventListener('scroll', update);
    return () => {
      if (!props.hasOwnProperty('value') && root?.addEventListener) root.removeEventListener('scroll', update);
    };
  }, [root]);
  React.useEffect(() => {
    if (value_ !== undefined && value_ !== refs.value.current) setValue(value_);
  }, [value_]);
  let styles = {};
  if (is('function', render)) styles = _objectSpread({}, render(value, root, rate, scrollDirection, transformDirection, transition, props));else {
    let valueUpdate = 0;
    if (is('function', rate)) valueUpdate = rate(value);else valueUpdate = value * rate;
    if (transformDirection === 'vertical') styles.transform = `translate3d(0, ${valueUpdate}%, 0)`;else styles.transform = `translate3d(${valueUpdate}%, 0, 0)`;
    styles.transition = transition;
  }
  return is('function', children) ? children(value, styles, other) : /*#__PURE__*/React.cloneElement(children, _objectSpread({
    className: classNames([staticClassName('Parallax', theme) && [`onesy-Parallax-root`], className, classes.root]),
    ref: item => {
      if (ref) {
        if (is('function', ref)) ref(item);else ref.current = item;
      }
      refs.root.current = item;
      if (children.ref) {
        if (is('function', children.ref)) children.ref(item);else children.ref.current = item;
      }
    },
    style: _objectSpread(_objectSpread({}, children.props.style), styles)
  }, other));
});
Parallax.displayName = 'onesy-Parallax';
export default Parallax;

==> ui-react-1.1.440.tgz: package/esm/Parallax/Parallax.js <==
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
const _excluded = ["value", "root", "render", "rate", "scrollDirection", "transformDirection", "transition", "disabled", "className", "style", "children"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
import React from 'react';
import { is, clamp } from '@amaui/utils';
import { classNames, style as styleMethod, useAmauiTheme } from '@amaui/style-react';
import useMediaQuery from '../useMediaQuery';
import { valueBreakpoints, staticClassName } from '../utils';
const useStyle = styleMethod(theme => ({
  root: {}
}), {
  name: 'amaui-Parallax'
});
const Parallax = /*#__PURE__*/React.forwardRef((props_, ref) => {
  const theme = useAmauiTheme();
  const props = React.useMemo(() => _objectSpread(_objectSpread(_objectSpread({}, theme?.ui?.elements?.all?.props?.default), theme?.ui?.elements?.amauiParallax?.props?.default), props_), [props_]);
  const {
      value: value_,
      // element
      root = window.document,
      render,
      // value or a method
      rate = -1,
      scrollDirection = 'vertical',
      transformDirection = 'vertical',
      transition = `transform ${theme.transitions.duration.xxs}`,
      disabled: disabled_,
      className,
      style,
      children
    } = props,
    other = _objectWithoutProperties(props, _excluded);
  const {
    classes
  } = useStyle();
  const refs = {
    root: React.useRef(),
    value: React.useRef(),
    scrollDirection: React.useRef(),
    transformDirection: React.useRef(),
    rate: React.useRef(),
    disabled: React.useRef()
  };
  const breakpoints = {};
  theme.breakpoints.keys.forEach(key => {
    if (theme.breakpoints.media[key]) breakpoints[key] = useMediaQuery(theme.breakpoints.media[key], {
      element: refs.root.current
    });
  });
  const disabled = valueBreakpoints(disabled_, false, breakpoints, theme);
  const [value, setValue] = React.useState(0);
  refs.value.current = value;
  refs.scrollDirection.current = scrollDirection;
  refs.transformDirection.current = transformDirection;
  refs.rate.current = rate;
  refs.disabled.current = disabled;
  const update = () => {
    let valueNew;
    if (refs.disabled.current) return;

    // Element rect
    const rect = refs.root.current.getBoundingClientRect();

    // Viewport
    if (
    // Vertically
    (
    // Element in view
    rect.y >= 0 && rect.bottom <= window.innerHeight ||
    // Element y out of view, but bottom in view
    rect.y < 0 && rect.bottom >= 0 ||
    // Element bottom out of view, but y in view
    rect.bottom > window.innerHeight && rect.y <= window.innerHeight) && (
    // Horizontally

    // Element in view
    rect.x >= 0 && rect.right <= window.innerWidth ||
    // Element x out of view, but right in view
    rect.x < 0 && rect.right >= 0 ||
    // Element right out of view, but x in view
    rect.right > window.innerWidth && rect.y <= window.innerWidth)) {
      const padding = Math.abs((window.innerHeight - rect.height) / 2);
      const max = rect.height + padding;
      valueNew = ((window.innerHeight - rect.y) / max - 1) * 100;
    }
    if (valueNew !== undefined && valueNew !== refs.value.current) setValue(clamp(valueNew, -100, 100));
  };
  React.useEffect(() => {
    // Update on init
    if (!props.hasOwnProperty('value')) update();
  }, []);
  React.useEffect(() => {
    if (!props.hasOwnProperty('value') && root?.addEventListener) root.addEventListener('scroll', update);
    return () => {
      if (!props.hasOwnProperty('value') && root?.addEventListener) root.removeEventListener('scroll', update);
    };
  }, [root]);
  React.useEffect(() => {
    if (value_ !== undefined && value_ !== refs.value.current) setValue(value_);
  }, [value_]);
  let styles = {};
  if (is('function', render)) styles = _objectSpread({}, render(value, root, rate, scrollDirection, transformDirection, transition, props));else {
    let valueUpdate = 0;
    if (is('function', rate)) valueUpdate = rate(value);else valueUpdate = value * rate;
    if (transformDirection === 'vertical') styles.transform = `translate3d(0, ${valueUpdate}%, 0)`;else styles.transform = `translate3d(${valueUpdate}%, 0, 0)`;
    styles.transition = transition;
  }
  return is('function', children) ? children(value, styles, other) : /*#__PURE__*/React.cloneElement(children, _objectSpread({
    className: classNames([staticClassName('Parallax', theme) && [`amaui-Parallax-root`], className, classes.root]),
    ref: item => {
      if (ref) {
        if (is('function', ref)) ref(item);else ref.current = item;
      }
      refs.root.current = item;
      if (children.ref) {
        if (is('function', children.ref)) children.ref(item);else children.ref.current = item;
      }
    },
    style: _objectSpread(_objectSpread({}, children.props.style), styles)
  }, other));
});
Parallax.displayName = 'amaui-Parallax';
export default Parallax;
